@@ -1,8 +1,9 @@
 # ! DO NOT MANUALLY INVOKE THIS setup.py, USE CATKIN INSTEAD
 
-from distutils.core import setup
 from catkin_pkg.python_setup import generate_distutils_setup
 
+from setuptools import setup
+
 # fetch values from package.xml
 setup_args = generate_distutils_setup(
     packages=['camera_calibration_parsers'],
